==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/CustomContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CustomContourValueResolverEventArgsDescriptionMetadata } from "./CustomContourValueResolverEventArgsDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { CustomContourValueResolverDescription } from "./CustomContourValueResolverDescription";
/**
 * @hidden
 */
export let CustomContourValueResolverDescriptionMetadata = /*@__PURE__*/ (() => {
    class CustomContourValueResolverDescriptionMetadata extends Base {
        static b(a) {
            if (CustomContourValueResolverDescriptionMetadata.a == null) {
                CustomContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CustomContourValueResolverDescriptionMetadata.c(CustomContourValueResolverDescriptionMetadata.a);
            }
            if (a.j(CustomContourValueResolverDescriptionMetadata.a)) {
                return;
            }
            a.y(CustomContourValueResolverDescriptionMetadata.a);
            CustomContourValueResolverEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            ContourValueResolverDescriptionMetadata.c(a);
            a.item("GetCustomContourValuesRef", "EventRef::getCustomContourValues");
        }
        static d(a) {
            CustomContourValueResolverDescriptionMetadata.b(a);
            a.aa("CustomContourValueResolver", () => new CustomContourValueResolverDescription());
            a.z("CustomContourValueResolver", CustomContourValueResolverDescriptionMetadata.a);
        }
    }
    CustomContourValueResolverDescriptionMetadata.$t = /*@__PURE__*/ markType(CustomContourValueResolverDescriptionMetadata, 'CustomContourValueResolverDescriptionMetadata');
    CustomContourValueResolverDescriptionMetadata.a = null;
    return CustomContourValueResolverDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CustomContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CustomContourValueResolverEventArgsDescriptionMetadata } from "./CustomContourValueResolverEventArgsDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { CustomContourValueResolverDescription } from "./CustomContourValueResolverDescription";
/**
 * @hidden
 */
export let CustomContourValueResolverDescriptionMetadata = /*@__PURE__*/ (() => {
    class CustomContourValueResolverDescriptionMetadata extends Base {
        static b(a) {
            if (CustomContourValueResolverDescriptionMetadata.a == null) {
                CustomContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CustomContourValueResolverDescriptionMetadata.c(CustomContourValueResolverDescriptionMetadata.a);
            }
            if (a.k(CustomContourValueResolverDescriptionMetadata.a)) {
                return;
            }
            a.aa(CustomContourValueResolverDescriptionMetadata.a);
            CustomContourValueResolverEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            ContourValueResolverDescriptionMetadata.c(a);
            a.item("GetCustomContourValuesRef", "EventRef::getCustomContourValues");
        }
        static d(a) {
            CustomContourValueResolverDescriptionMetadata.b(a);
            a.ac("CustomContourValueResolver", () => new CustomContourValueResolverDescription());
            a.ab("CustomContourValueResolver", CustomContourValueResolverDescriptionMetadata.a);
        }
    }
    CustomContourValueResolverDescriptionMetadata.$t = /*@__PURE__*/ markType(CustomContourValueResolverDescriptionMetadata, 'CustomContourValueResolverDescriptionMetadata');
    CustomContourValueResolverDescriptionMetadata.a = null;
    return CustomContourValueResolverDescriptionMetadata;
})();
